from django.db import models
#from clmainApp.models import Branch,HourSlot,User,WeekDay,AlertMessage
from clmainApp.models import Branch,HourSlot,User,WeekDay
from clhrApp.models import DrLevel

class Location(models.Model): 
    name = models.CharField(max_length=100,unique=True)
    branch = models.ForeignKey(Branch,on_delete=models.PROTECT,blank=True,null=True)
    created_at = models.DateTimeField(auto_now_add=True)
    created_by = models.ForeignKey(
        User,
        related_name="Location_created_by",
        blank=True,
        null=True,
        on_delete=models.PROTECT,
    )
    def __str__(self):
        return self.name
    class Meta:
        unique_together = ("branch", "name")
# Create your models here.
class ActiveHourSlot(models.Model):
    branch = models.ForeignKey(Branch,on_delete=models.PROTECT)   
    hour_slot = models.ForeignKey(HourSlot,blank=True,null=True,on_delete=models.PROTECT)
    def __str__(self):
        return self.name
    class Meta:    
        unique_together = (("branch", "hour_slot"))

class DrWorkingDay(models.Model):
    branch = models.ForeignKey(Branch,on_delete=models.PROTECT)
    dr = models.ForeignKey(User,on_delete=models.PROTECT) 
    weekday = models.ForeignKey(WeekDay,on_delete=models.PROTECT)
    # def __str__(self):
    #     return self.name
    class Meta:    
        unique_together = (("branch", "dr","weekday"))


class DrData(models.Model):
    branch = models.ForeignKey(Branch,on_delete=models.PROTECT)
    dr = models.ForeignKey(User,on_delete=models.PROTECT) 
    dr_level = models.ForeignKey(DrLevel,on_delete=models.PROTECT)
    month_salary = models.IntegerField(default=0)
    salary_phone_number = models.CharField(default="0",max_length=20)#phone number to transfer salary
    is_active =  models.BooleanField(default=False)
    def __str__(self):
        return f"{self.dr.name} {self.dr_level.name}"
    class Meta:    
        unique_together = ("branch", "dr")

from django.utils import timezone
from clhrApp.models import Earning,Deduction
class DrSalary(models.Model):
    total_amount = models.IntegerField(default=0)# elli hytdf3 lel employee # elmost7ak
    total_earning = models.IntegerField(default=0)
    total_deduction = models.IntegerField(default=0)
    total_ssn_amount = models.IntegerField(default=0)
    total_ssn_bonus = models.IntegerField(default=0)
    total_ssn_deduction = models.IntegerField(default=0)
    dr_data =  models.ForeignKey(
        DrData,
        related_name="DrSalary_dr_data",
        on_delete=models.PROTECT,
    )
    from_day = models.DateField(blank=True,null=True)
    to_day = models.DateField(blank=True,null=True)
    created_by = models.ForeignKey(User,related_name="DrSalary_created_by",on_delete=models.PROTECT)# اللي حسب المرتب وحط الرقم النهائي 
    created_at = models.DateTimeField(default=timezone.now)#تاريخ إنشاء المرتب 
    #when employee salary delivered to him 
    pay_day = models.DateField(blank=True,null=True)#تاريخ التسليم للموظف 
    deliver_notes = models.CharField(max_length=200,blank=True,null=True) # ملاحظات التسليم 
    delivered_by = models.ForeignKey(User,related_name="DrSalary_delivered_by",on_delete=models.PROTECT,null=True)# اللي سلم الفلوس للموظف 
   
    def __str__(self):
        return "{}-{}".format(self.dr_data.dr.fullname,str(self.total_amount))


class DrDeduction(models.Model):
    amount = models.IntegerField(default=0)
    dr_data =  models.ForeignKey(
        DrData,
        related_name="DrDeduction_dr_data",
        on_delete=models.PROTECT,
    )
    deduction =  models.ForeignKey(
        Deduction,
        related_name="DrDeduction_deduction",
        on_delete=models.PROTECT,
    )
    salary = models.ForeignKey(DrSalary,on_delete=models.PROTECT,null=True)
    is_done = models.BooleanField(default=False,help_text='select if month is finished w kol 7aga 5adha el mowzf most7akato')
    deduction_note = models.CharField(max_length=120,blank=True,null=True)
    created_by = models.ForeignKey(User,on_delete=models.PROTECT)
    created_at = models.DateTimeField(default=timezone.now)

    def __str__(self):
        return "{}__{}__{}".format(self.dr_data.dr.name,self.deduction.name,str(self.amount))

class DrEarning(models.Model):
    amount = models.IntegerField(default=0)
    dr_data =  models.ForeignKey(
        DrData,
        related_name="DrEarning_dr_data",
        on_delete=models.PROTECT,
    )
    earning =  models.ForeignKey(
        Earning,
        related_name="DrEarning_earning",
        on_delete=models.PROTECT,
    )
    salary = models.ForeignKey(DrSalary,on_delete=models.PROTECT,null=True)
    is_done = models.BooleanField(default=False,help_text='select if month is finished w kol 7aga 5adha el mowzf most7akato')
    earning_note = models.CharField(max_length=120,blank=True,null=True)
    created_by = models.ForeignKey(User,on_delete=models.PROTECT)
    created_at = models.DateTimeField(default=timezone.now)

    def __str__(self):
        return "{}__{}__{}".format(self.dr_data.dr.name,self.earning.name,str(self.amount))
# class BranchDailyAlertMessage(models.Model):
#     branch = models.ForeignKey(Branch,on_delete=models.PROTECT)   
#     active_message = models.ForeignKey(AlertMessage,blank=True,null=True,on_delete=models.PROTECT)
#     #def __str__(self):
#         #return self.name
#     class Meta:    
#         unique_together = (("branch", "active_message"))

# class BranchAlertMessage(models.Model):
#     branch = models.ForeignKey(Branch,on_delete=models.PROTECT)   
#     active_message = models.ForeignKey(AlertMessage,blank=True,null=True,on_delete=models.PROTECT)
#     #def __str__(self):
#         #return self.name
#     class Meta:    
#         unique_together = (("branch", "active_message"))

